export interface UseAsyncOperationOptions {
    finishedTimeout?: number;
    singleton?: boolean;
}
export interface UseAsyncOperationState {
    loading: number;
    finished: boolean;
}
/**
 * Allows to observe the status of async operation (loading, finished)
 * @param callback - async callback which performs the operation
 * @param options - hook options:
 *  - singleton - prevents calling operation until previous call is finished
 *  - finishedTimeout - if set, after operation is completed, sets value of
 *      finished to true for the given number of milliseconds. To set finished
 *      permanently, set finishedTimeout to Infinity
 * @example
 *  const [run, loading] = useAsyncOperation(() => fetch('url').catch(e => console.error(e)));
 *  return <div>{loading ? 'Loading...' : <button onClick={run} />}
 */
export declare function useAsyncOperation<Args extends any[], Result>(callback: (...args: Args) => Promise<Result>, options?: UseAsyncOperationOptions): {
    run: (...args: Args) => Promise<void> | Promise<Result>;
    loading: boolean;
    finished: boolean;
    setFinished: (finished: boolean) => void;
};
