import { useCallback, useState } from 'react';
import { useLatestCallbackRef, useMountedRef } from "@proscom/ui-react";
/**
 * Allows to observe the status of async operation
 * @param callback - async callback which performs the operation
 * @example
 *  const [run, loading] = useAsyncOperation(() => fetch('url').catch(e => console.error(e)));
 *  return <div>{loading ? 'Loading...' : <button onClick={run} />}
 */
export function useAsyncOperationBasic(callback) {
    var _a = useState(0), loading = _a[0], setLoading = _a[1];
    var mountedRef = useMountedRef();
    var callbackRef = useLatestCallbackRef(callback);
    var run = useCallback(function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        setLoading(function (s) { return s + 1; });
        return callbackRef.apply(void 0, args).then(function (result) {
            if (mountedRef.current) {
                setLoading(function (s) { return s - 1; });
            }
            return result;
        }, function (e) {
            if (mountedRef.current) {
                setLoading(function (s) { return s - 1; });
            }
            throw e;
        });
    }, []);
    return [run, loading > 0];
}
//# sourceMappingURL=useAsyncOperationBasic.js.map